@@ -12,7 +12,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized numeric once );
 
-our $VERSION = '1.801';
+our $VERSION = '1.802';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitExplicitReturnUndef)
@@ -46,14 +46,13 @@ BEGIN {
    eval 'PDL::no_clone_skip_warning()' if $INC{'PDL.pm'};
    eval 'use PDL::IO::Storable' if $INC{'PDL.pm'};
 
-   if (!exists $INC{'PDL.pm'}) {
+   if ($] >= 5.012 && !exists $INC{'PDL.pm'}) {
       eval 'use Sereal 3.008 qw( encode_sereal decode_sereal )';
       if ( !$@ ) {
          $_freeze = sub { encode_sereal( @_, { freeze_callbacks => 1 } ) };
          $_thaw   = \&decode_sereal;
       }
    }
-
    if (!defined $_freeze) {
       require Storable;
       $_freeze = \&Storable::freeze;
@@ -2267,7 +2266,7 @@ MCE::Shared::Server - Server/Object packages for MCE::Shared
 
 =head1 VERSION
 
-This document describes MCE::Shared::Server version 1.801
+This document describes MCE::Shared::Server version 1.802
 
 =head1 DESCRIPTION
 
